==> activity-center-biz-1.0.2-20160622.061036-30-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/seconds_kill/RemoteDuibaSecondsKillActivityAppSpecifyServiceImpl.java <==
package cn.com.duiba.activity.center.biz.remoteservice.impl.seconds_kill;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.seconds_kill.DuibaSecondsKillActivityAppSpecifyDto;
import cn.com.duiba.activity.center.api.remoteservice.seconds_kill.RemoteDuibaSecondsKillActivityAppSpecifyService;
import cn.com.duiba.activity.center.biz.service.seconds_kill.DuibaSecondsKillActivityAppSpecifyService;

/**
 * Created by wenqi.huang on 16/5/24.
 */
@Service
public class RemoteDuibaSecondsKillActivityAppSpecifyServiceImpl implements RemoteDuibaSecondsKillActivityAppSpecifyService {
    @Resource
    private DuibaSecondsKillActivityAppSpecifyService duibaSecondsKillActivityAppSpecifyService;

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto findByDuibaActivityAndApp(Long duibaSecondsKillActivityId, Long appId) {
        return duibaSecondsKillActivityAppSpecifyService.findByDuibaActivityAndApp(duibaSecondsKillActivityId, appId);
    }

    @Override
    public List<DuibaSecondsKillActivityAppSpecifyDto> findByDuibaSecondsKillActivityId(Long duibaSecondsKillActivityId) {
        return duibaSecondsKillActivityAppSpecifyService.findByDuibaSecondsKillActivityId(duibaSecondsKillActivityId);
    }

    @Override
    public void insert(DuibaSecondsKillActivityAppSpecifyDto duibaSecondsKillActivityAppSpecify) {
        duibaSecondsKillActivityAppSpecifyService.insert(duibaSecondsKillActivityAppSpecify);
    }

    @Override
    public void delete(Long id) {
        duibaSecondsKillActivityAppSpecifyService.delete(id);
    }

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto find(Long id) {
        return duibaSecondsKillActivityAppSpecifyService.find(id);
    }

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto findByDuibaSecondsKillActivityAndApp(Long duibaSecondsKillActivityId, Long appId) {
        return duibaSecondsKillActivityAppSpecifyService.findByDuibaSecondsKillActivityAndApp(duibaSecondsKillActivityId, appId);
    }
}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/seconds_kill/RemoteDuibaSecondsKillActivityAppSpecifyServiceImpl.java <==
package cn.com.duiba.activity.center.biz.remoteservice.impl.seconds_kill;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.seconds_kill.DuibaSecondsKillActivityAppSpecifyDto;
import cn.com.duiba.activity.center.api.remoteservice.seconds_kill.RemoteDuibaSecondsKillActivityAppSpecifyService;
import cn.com.duiba.activity.center.biz.service.seconds_kill.DuibaSecondsKillActivityAppSpecifyService;

/**
 * Created by wenqi.huang on 16/5/24.
 */
@Service
public class RemoteDuibaSecondsKillActivityAppSpecifyServiceImpl implements RemoteDuibaSecondsKillActivityAppSpecifyService {
    @Resource
    private DuibaSecondsKillActivityAppSpecifyService duibaSecondsKillActivityAppSpecifyService;

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto findByDuibaActivityAndApp(Long duibaSecondsKillActivityId, Long appId) {
        return duibaSecondsKillActivityAppSpecifyService.findByDuibaActivityAndApp(duibaSecondsKillActivityId, appId);
    }

    @Override
    public List<DuibaSecondsKillActivityAppSpecifyDto> findByDuibaSecondsKillActivityId(Long duibaSecondsKillActivityId) {
        return duibaSecondsKillActivityAppSpecifyService.findByDuibaSecondsKillActivityId(duibaSecondsKillActivityId);
    }

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto insert(DuibaSecondsKillActivityAppSpecifyDto duibaSecondsKillActivityAppSpecify) {
        duibaSecondsKillActivityAppSpecifyService.insert(duibaSecondsKillActivityAppSpecify);
        return duibaSecondsKillActivityAppSpecify;
    }

    @Override
    public void delete(Long id) {
        duibaSecondsKillActivityAppSpecifyService.delete(id);
    }

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto find(Long id) {
        return duibaSecondsKillActivityAppSpecifyService.find(id);
    }

    @Override
    public DuibaSecondsKillActivityAppSpecifyDto findByDuibaSecondsKillActivityAndApp(Long duibaSecondsKillActivityId, Long appId) {
        return duibaSecondsKillActivityAppSpecifyService.findByDuibaSecondsKillActivityAndApp(duibaSecondsKillActivityId, appId);
    }
}
